#### 爬虫辅助工具--headersformat
----------------
#####  一、安装
```bash
pip3 install headersformat -i https://pypi.org/project/
```
##### 二、使用示例

```python3
#!/usr/bin/python3
# -*- coding: utf-8 -*-
# @Time    : 2022/9/15 9:26
from headersformat import headers_foramt
headers_foramt()
```
![在这里插入图片描述](https://img-blog.csdnimg.cn/fd8ab6e4990a4dde9628c745d30bb5c9.png)

